// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:wyatt_component_copy_with_extension/wyatt_component_copy_with_extension.dart';
import 'package:wyatt_ui_components/wyatt_ui_components.dart';
import 'package:wyatt_ui_kit/src/components/cards/pricing_card/widgets/pricing_card_features.dart';
import 'package:wyatt_ui_kit/src/components/cards/pricing_card/widgets/pricing_card_titles.dart';
import 'package:wyatt_ui_kit/src/components/cards/widgets/card_text.dart';
import 'package:wyatt_ui_kit/src/components/cards/widgets/card_wrapper.dart';
import 'package:wyatt_ui_kit/src/core/design_system/colors.dart';
import 'package:wyatt_ui_kit/wyatt_ui_kit.dart';

part 'pricing_card.g.dart';

const _bodyTopSpacing = 25.0;

@ComponentCopyWithExtension()
class PricingCard extends PricingCardComponent with $PricingCardCWMixin {
  const PricingCard({
    super.axis,
    super.title,
    super.pricing,
    super.description,
    super.features,
    super.cta,
    super.radius,
    super.padding,
    super.borderColors,
    super.backgroundColors,
    super.stroke,
    super.minSize,
    super.maxSize,
    super.shadow,
    super.titleStyle,
    super.subtitleStyle,
    super.bodyStyle,
    super.background,
    super.key,
  });

  @override
  Widget build(BuildContext context) {
    final themeTitleStyle = ThemeHelper.maybeGetElement<TextStyle, TextStyle>(
      [
        titleStyle,
        Theme.of(context).extension<CardThemeExtension>()?.titleStyle,
        CardThemeExtensionDefault.from(Theme.of(context)).titleStyle,
      ],
    );

    final themePricingStyle = ThemeHelper.maybeGetElement<TextStyle, TextStyle>(
      [
        pricing?.price.style,
        context.textTheme.bodyMedium
            ?.copyWith(fontSize: 50, fontWeight: FontWeight.bold),
      ],
    );

    final themePeriodStyle = ThemeHelper.maybeGetElement<TextStyle, TextStyle>(
      [
        subtitleStyle,
        context.textTheme.bodyMedium?.copyWith(
          fontSize: 20,
          fontWeight: FontWeight.w600,
          color: WyattColors.gray1,
        ),
      ],
    );

    final themeBodyStyle = ThemeHelper.maybeGetElement<TextStyle, TextStyle>(
      [
        bodyStyle,
        Theme.of(context).extension<CardThemeExtension>()?.bodyStyle,
        CardThemeExtensionDefault.from(Theme.of(context)).bodyStyle,
      ],
    );

    return CardWrapper(
      background: background,
      padding: padding,
      radius: radius,
      backgroundColors: backgroundColors,
      borderColors: borderColors,
      shadow: shadow,
      stroke: stroke,
      maxSize: maxSize,
      minSize: minSize,
      child: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          PricingCardTitles(
            axis: axis,
            title: title,
            pricing: pricing,
            titleStyle: themeTitleStyle,
            pricingStyle: themePricingStyle,
            periodStyle: themePeriodStyle,
          ),
          const Gap(_bodyTopSpacing),
          if (description != null) ...[
            CardText.fromWrapper(
              description!,
              style: themeBodyStyle,
            ),
            const Gap(_bodyTopSpacing),
          ],
          if (features != null) ...[
            PricingCardFeatures(
              features: features,
              bodyStyle: themeBodyStyle,
            ),
            const Gap(_bodyTopSpacing),
          ],
          if (cta != null) ...[
            SelectionContainer.disabled(child: cta!),
          ],
        ],
      ),
    );
  }
}
