// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:wyatt_ui_components/wyatt_ui_components.dart';
import 'package:wyatt_ui_kit/src/core/design_system/colors.dart';

class FileSelectionButtonThemeExtensionImpl
    extends FileSelectionButtonThemeExtension {
  const FileSelectionButtonThemeExtensionImpl({
    super.disabledStyle,
    super.focusedStyle,
    super.hoveredStyle,
    super.normalStyle,
    super.tappedStyle,
    super.selectedStyle,
    super.invalidStyle,
  });

  factory FileSelectionButtonThemeExtensionImpl.light({ThemeData? theme}) {
    theme ??= ThemeData.light();
    final style = FileSelectionButtonStyle(
      titleStyle: theme.textTheme.labelLarge,
      subtitleStyle: theme.textTheme.labelSmall,
      radius: BorderRadius.circular(12),
      padding: const EdgeInsets.all(13),
      foregroundColors: const MultiColor.single(WyattColors.black),
      backgroundColors: const MultiColor.single(WyattColors.light),
      borderColors: MultiColor.single(WyattColors.black.withOpacity(0.4)),
      stroke: 2,
      animationDuration: const Duration(milliseconds: 150),
    );
    return FileSelectionButtonThemeExtensionImpl(
      normalStyle: style,
      disabledStyle: style.copyWith(
        foregroundColors: MultiColor.single(WyattColors.black.withOpacity(0.4)),
        backgroundColors: const MultiColor.single(WyattColors.light),
        borderColors: WyattColors.lightGradient,
      ),
      hoveredStyle: style.copyWith(
        backgroundColors:
            MultiColor.single(WyattColors.black.withOpacity(0.04)),
      ),
      focusedStyle: style.copyWith(stroke: 4),
      tappedStyle: style.copyWith(
        backgroundColors: MultiColor.single(WyattColors.black.withOpacity(0.1)),
      ),
      invalidStyle: style.copyWith(
        subtitleStyle: theme.textTheme.labelSmall?.copyWith(
          fontSize: 11,
          fontWeight: FontWeight.w400,
          color: WyattColors.red1,
        ),
        borderColors: WyattColors.redGradient,
      ),
      // Unused
      selectedStyle: style.copyWith(
        foregroundColors: const MultiColor.single(WyattColors.black),
        borderColors: WyattColors.greenGradient,
      ),
    );
  }

  factory FileSelectionButtonThemeExtensionImpl.dark({ThemeData? theme}) {
    theme ??= ThemeData.dark();
    final style = FileSelectionButtonStyle(
      titleStyle: theme.textTheme.labelLarge,
      subtitleStyle: theme.textTheme.labelSmall,
      radius: BorderRadius.circular(12),
      padding: const EdgeInsets.all(13),
      foregroundColors: const MultiColor.single(WyattColors.light),
      backgroundColors: const MultiColor.single(WyattColors.black),
      borderColors: MultiColor.single(WyattColors.light.withOpacity(0.4)),
      stroke: 2,
      animationDuration: const Duration(milliseconds: 150),
    );
    return FileSelectionButtonThemeExtensionImpl(
      normalStyle: style,
      disabledStyle: style.copyWith(
        foregroundColors:
            MultiColor.single(WyattColors.light.withOpacity(0.04)),
        backgroundColors: const MultiColor.single(WyattColors.black),
        borderColors: MultiColor.single(WyattColors.light.withOpacity(0.04)),
      ),
      hoveredStyle: style.copyWith(
        backgroundColors:
            MultiColor.single(WyattColors.light.withOpacity(0.04)),
      ),
      focusedStyle: style.copyWith(stroke: 4),
      tappedStyle: style.copyWith(
        backgroundColors: MultiColor.single(WyattColors.light.withOpacity(0.1)),
      ),
      invalidStyle: style.copyWith(
        subtitleStyle: theme.textTheme.labelSmall?.copyWith(
          fontSize: 11,
          fontWeight: FontWeight.w400,
          color: WyattColors.red1,
        ),
        borderColors: WyattColors.redGradient,
      ),
      // Unused
      selectedStyle: style.copyWith(
        foregroundColors: const MultiColor.single(WyattColors.light),
        borderColors: WyattColors.greenGradient,
      ),
    );
  }
}
